//
//  UNCMusicDetailsViewController.m
//  MusicList
//
//  Created by Calvin Stephens IV on 4/3/12.
//  Copyright (c) 2012 Unicode Concepts. All rights reserved.
//

#import "UNCMusicDetailsViewController.h"

@interface UNCMusicDetailsViewController ()

@end

@implementation UNCMusicDetailsViewController

@synthesize albumTextField;
@synthesize artistTextField;
@synthesize toolBar;
@synthesize music;
@synthesize delegate;

- (id)init
{
    if (self = [super initWithNibName:@"UNCMusicDetailsViewController" bundle:nil]) {
        
    }
    
    return self;
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    return [self init];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
     self.title = NSLocalizedString(@"Music Details", @"Music Details");
    // Do any additional setup after loading the view from its nib.
    
    self.albumTextField.text = self.music.album;
    self.artistTextField.text = self.music.artist;
    
    [self setupButtonsForEditing:NO];
    
    self.toolBar.tintColor = [UIColor grayColor];
    
    UIBarButtonItem *deleteButton = [self.toolBar.items objectAtIndex:0];
    deleteButton.target = self;
    deleteButton.action = @selector(confirmDelete);
}

#pragma mark - Editing mode

- (void)setEditing:(BOOL)editing animated:(BOOL)animated
{
    [super setEditing:editing animated:animated];
    [self setupButtonsForEditing:editing];
    
    if (editing) {
        [self.albumTextField becomeFirstResponder];
    } else {
        [self.albumTextField resignFirstResponder];
        [self.artistTextField resignFirstResponder];
    }
}

- (void)setupButtonsForEditing:(BOOL)editing
{
    if (editing) {
            // cancel button
        UIBarButtonItem *leftButton = [[UIBarButtonItem alloc] initWithTitle:@"Cancel"
                                                                       style:UIBarButtonItemStyleBordered
                                                                      target:self
                                                                      action:@selector(cancelEdit)];
        [self.navigationItem setLeftBarButtonItem:leftButton
                                         animated:YES];
        
            // save button
        UIBarButtonItem *rightButton = [[UIBarButtonItem alloc] initWithTitle:@"Save"
                                                                        style:UIBarButtonItemStyleBordered
                                                                       target:self
                                                                       action:@selector(saveItem)];
        [self.navigationItem setRightBarButtonItem:rightButton
                                          animated:YES];
        
    } else {
            // back button
        [self.navigationItem setLeftBarButtonItem:self.navigationItem.backBarButtonItem
                                         animated:YES];
        
            // edit button
        UIBarButtonItem *rightButton = [[UIBarButtonItem alloc] initWithTitle:@"Edit"
                                                                        style:UIBarButtonItemStyleBordered
                                                                       target:self
                                                                       action:@selector(editItem)];
        
        [self.navigationItem setRightBarButtonItem:rightButton
                                          animated:YES];
    }
}

- (void)editItem
{
    NSLog(@"Edit item");
    [self setEditing:YES animated:YES];
}
 
- (void)cancelEdit
{
    NSLog(@"Cancel edit");
    [self setEditing:NO animated:YES];
}

- (void)saveItem
{
    NSLog(@"Save item");
    [self setEditing:NO animated:YES];
    
    self.music.album = self.albumTextField.text;
    self.music.artist = self.artistTextField.text;
    
    if ([self.delegate respondsToSelector:@selector(musicDetailsViewController:didUpdateMusic:)]) {
        [self.delegate musicDetailsViewController:self didUpdateMusic:self.music];
    }
}

#pragma mark - Toolbar actions

- (void)confirmDelete
{
    UIActionSheet *actionSheet = [[UIActionSheet alloc] initWithTitle:@"Are you sure?"
                                                             delegate:self
                                                    cancelButtonTitle:@"Cancel"
                                               destructiveButtonTitle:@"Delete"
                                                    otherButtonTitles:nil];
    actionSheet.delegate = self;
    
    [actionSheet showFromToolbar:self.toolBar];
}

#pragma mark - UIActionSheetDelegate

- (void)actionSheet:(UIActionSheet *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex
{
    if (buttonIndex == 0) {
        [self deleteItem];
    }
}

- (void)deleteItem
{
    NSLog(@"deleting music item");
    
    if ([self.delegate respondsToSelector:@selector(musicDetailsViewController:didAskToDeleteMusic:)]) {
        [self.delegate musicDetailsViewController:self didAskToDeleteMusic:self.music];
    }
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
}

@end
